@@ -17,10 +17,20 @@ if sys.version_info[0] >= 3:
     from urllib.parse import urlencode
     from urllib.request import urlopen
     from urllib.error import HTTPError
+    _str_type = str
 else:
     from urllib import urlencode
     from urllib2 import urlopen
     from urllib2 import HTTPError
+    _str_type = basestring
+
+
+def safe_encode(kwargs):
+    kwargs = kwargs.copy()
+    for k, v in kwargs.iteritems():
+        if isinstance(v, _str_type):
+            kwargs[k] = v.encode('utf8')
+    return urlencode(kwargs)
 
 
 class Service:
@@ -68,6 +78,6 @@ class Service:
 
             ex.url = e.geturl()
             ex.message = message
-            ex.code    = code
+            ex.code = code
 
             raise ex
